/**
 * Description of module:
 * Libreria que inicializa el modulo DS3231 por I2C,
 * lee y escribe los valores de la fecha y hora en el.
 *
 * author Jorge Saiz Gil
 *
 * revision 1.0 date 18/04/2016
 */

#ifndef _DS3231_H_
#define _DS3231_H

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/
#include <LPC17xx.h>
#include <TimeTools.h>

/*-----------------------------------------------------------
 * DEFINICIONES
 *----------------------------------------------------------*/
#define START_REG		0x00 //direccion de memoria donde se inicia la lectura de datos del DS3231

/*-----------------------------------------------------------
 * DECLARACIONES
 *----------------------------------------------------------*/

/** Inicializa el dispositivo I2C, RTC DS3231
*
* @precondition 		El numero de puerto esta dentro de los disponibles, solo el 0.
*
* @param i2c_port   	uint8_t, indica el puerto I2C
* @param i2c_address  	uint8_t, direccion de memoria del dispostivo I2C
* @param i2c_freq  		uint32_t, frecuencia de funcionamiento del DS3231
*
* @return NONE
*/
void DS3231_init(uint8_t i2c_port, uint8_t i2c_address, uint32_t i2c_freq);

/** Lee el valor de la fecha y hora almacenado en el DS3231 y lo devuelve
*
* @precondition 		El dispositivo esta inicializado
*
* @param t   			Timedate*, Puntero a variable Timedate donde se almacenara el valor obtenido
*
* @return NONE
*/
void DS3231_getTime(Timedate* t);

/** Almacena fecha y hora en el DS3231
*
* @precondition 		El dispositivo esta inicializado
*
* @param t   			Timedate*, Puntero a variable Timedate donde esta el valor a almacenar
*
* @return NONE
*/
void DS3231_setTime(Timedate *t);


#endif /* _DS3231_H_ */
