/**
 * Description of module:
 * Libreria para controlar la comunicacion a traves de I2C
 *
 * author Jorge Saiz Gil
 *
 * revision 1.0 date 18/04/2016
 */

#ifndef _I2C0_H_
#define _I2C0_H_
 
/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/
#include "LPC17xx.h"
 
/*-----------------------------------------------------------
 * DEFINITIONS
 *----------------------------------------------------------*/
 
// IC2 control BITS
#define AA     				(1 << 2)
#define SI      			(1 << 3)
#define STO     			(1 << 4)
#define STA     			(1 << 5)
#define I2EN    			(1 << 6)

/** Inicializa el puerto I2C0
*
* @precondition         NONE
*
* @param i2c_freq      	uint32_t, frecuencia en la que trabajara el puerto I2C
*
* @return NONE
*/
void I2C0_init(uint32_t i2c_freq);
 
/** Envia los datos pasados por parametro a traves de I2C0
*
* @precondition         	El dispostivo I2C debe estar inicializado
*
* @param address      		uint8_t, direccion del dispositivo I2C 
* @param I2C_Send_Buffer 	uint8_t*, Puntero a entero, direccion donde se almacenan los datos a enviar
* @param length      		uint32_t, longitud de los datos a enviar 
*
* @return NONE
*/
uint32_t I2C0_send(uint8_t address, uint8_t* I2C_Send_Buffer, uint32_t length);
 
/** Lee datos a traves de I2C0
*
* @precondition         	El dispostivo I2C debe estar inicializado
*
* @param address      		uint8_t, direccion del dispositivo I2C  
* @param I2C_Read_Buffer 	uint8_t*, Puntero  a entero, direccion donde se almacenaran los datos a leidos
* @param length      		uint32_t, longitud de los datos a leer 
*
* @return NONE
*/
uint32_t I2C0_receive(uint8_t address, uint8_t* I2C_Read_Buffer, uint32_t length);

/** Contrala las interrupciones del puertro I2C0
*
* @precondition         	El dispostivo I2C debe estar inicializado
*
* @return NONE
*/
void I2C0_IRQHandler(void) ;
 
#endif /* _I2C0_H_ */
