/**
 * Description of module:
 * Libreria para controlar la comunicacion con el panel de leds a traves de GPIOs
 *
 * author Jorge Saiz Gil
 *
 * revision 1.0 date 06/05/2016
 */

#ifndef LEDDISPLAY_H_
#define LEDDISPLAY_H_

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/

#include <LPC17xx.h>
#include <GPIO.h>
#include <TimeTools.h>

/*-----------------------------------------------------------
 * DEFINICIONES
 *----------------------------------------------------------*/

//Macros para asociar cada palabra del reloj de palabras con su correspondiente puerto GPIO
#define SON		 				P2_12
#define ES						P2_11
#define LA						P2_10
#define S						P2_8
#define UNA						P2_7
#define DOS						P2_6
#define TRES					P2_5
#define CUATRO					P2_4
#define CINCO					P2_3
#define SEIS					P2_2
#define SIETE					P2_1
#define OCHO					P2_0
#define NUEVE					P0_11
#define DIEZ					P0_10
#define ONCE					P0_5
#define DOCE					P0_4

#define Y						P0_7

#define MENOS					P1_31
#define VEINTE					P1_30
#define M_DIEZ					P0_26
#define VEINTI					P0_25
#define M_CINCO					P0_24
#define CUARTO					P0_23
#define MEDIA					P0_16
#define MIN1					P0_15
#define MIN2					P0_17
#define MIN3					P0_18

#define MIN4					P0_6

/*-----------------------------------------------------------
 * DECLARACIONES
 *----------------------------------------------------------*/

// definicion array con todas las palabras para agilizar la gestion de los puertos GPIO
static const uint8_t wordsInPanel[28] = {SON, ES, LA, S, UNA, DOS, TRES, CUATRO, CINCO, SEIS, SIETE, OCHO, NUEVE, DIEZ, ONCE, DOCE, Y, MENOS, VEINTE, M_DIEZ, VEINTI, M_CINCO, CUARTO, MEDIA, MIN1, MIN2, MIN3, MIN4};
static const uint8_t num_wordInPanel = 28;

/** Inicializa todos los pines asociados a las palabras como GPIO de salida
*
* @precondition         NONE
*
* @return NONE
*/
void LedDisplay_init();

/** Enciende los leds correspondientes al valor de la hora en el panel.
*
* @precondition 		Los puertos GPIO deben estar inicializados
*
* @param t  			Timedate*, Puntero a variable Timedate donde esta el valor de la hora
*
* @return NONE
*/
void LedDisplay_showTime( Timedate* t);



#endif /* LEDDISPLAY_H_ */
