/**
 * Description of module:
 * Libreria con herramientos para tratar y convertir valores de tiempo
 *
 * author Jorge Saiz Gil
 *
 * revision 1.0 date 03/05/2016
 */

#ifndef TIMETOOLS_H_
#define TIMETOOLS_H_


/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/

#include <LPC17xx.h>

/*-----------------------------------------------------------
 * DECLARACIONES
 *----------------------------------------------------------*/

//Definimos tipo de dato para almacenar los valores de fecha y hora.
typedef struct{
	uint8_t hour;
	uint8_t min;
	uint8_t sec;
	uint8_t date;
	uint8_t mon;
	uint8_t year;
	uint8_t day; //day of week
	uint8_t century; //0->19xx 1-> 20xx
}Timedate;

/** Convierte timestamp al tipo Timedate.
*
* @precondition 		NONE
*
* @param ts 			uint32_t, entero que contiene el 
* @param t 				Timedate*, puntero a variable Timedate donde se alamacenara el valor convertido
*
* @return NONE
*/
void Time_TimestamptoTimedate(uint32_t ts, Timedate* t);

/** Convierte tipo Timedate a timestamp.
*
* @precondition 		NONE
*
* @param t 				Timedate*, puntero a Timedate donde esta el valor a convertir
*
* @return Entero con el valor del timestamp convertiodo, uint32_t
*/
uint32_t Time_TimedatetoTimestamp(Timedate* t);

/** Ajusta la zona UTC (España +1) y comprueba si esta en horario de verano.
*
* @precondition 		NONE
*
* @param ts 			uint32_t, Entero donde esta el valor a actualizar
*
* @return Entero con el valor del timestamp ajustado, uint32_t
*/
uint32_t Time_adjustTimeZoneDST(uint32_t ts);

/** añade al timestamp el valor de delay pasado por parametro
*	 redondea el valor del delay que esta en Us a segundos.
*
* @precondition 		NONE
*
* @param ts 			uint32_t con el timestamp valor a actualizar
* @param syncDelayUs 	uint32_t donde esta el valor del delay a aplicar
*
* @return Entero con el valor del timestamp ajustado, uint32_t
*/
uint32_t Time_adjunstSyncDelay(uint32_t ts,uint32_t syncDelayUs);

/** Convierte de binario a decimal
*
* @precondition 		NONE
*
* @param d 			char, con el valor binario a convertir
*
* @return Valor decimal convertido, char
*/
char bcd_to_decimal(char d);

/** Convierte de decimal a binario
*
* @precondition 		NONE
*
* @param d 			unsigned char, con el valor decimal a convertir
*
* @return Valor binario convertido, unsigned char
*/
unsigned char decimal_to_bcd(unsigned char d);
#endif /* TIMETOOLS_H_ */
