/**
 * Description of module:
 * Libreria la controlar los timer del LPC
  *
 * author Jorge Saiz Gil
 *
 * revision 1.0 date 19/05/2016
 */


#ifndef TIMER_H_
#define TIMER_H_

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/
#include "LPC17xx.h"

/*-----------------------------------------------------------
 * DEFINITIONS
 *----------------------------------------------------------*/
#define TIMER_NUM0           0
#define TICS_PER_SECOND      1000000 //microsegundos

/** Inicializa el timer del LPC1769 pasado por parametro con precision de Us.
*
* @precondition 		NONE
*
* @param timerNumber 	uint8_t, entero con el numero de timer a inciar
*
* @return NONE
*/
void Timer_init(uint8_t timerNumber);

/** Inicia el contador del timer pasado por parametro.
*
* @precondition 		El timer tiene que estas inicializado.
*
* @param timerNumber 	uint8_t, entero con el numero de timer a inciar
*
* @return NONE
*/
void Timer_Start(uint8_t timerNumber);

/** Detiene el contador del timer pasado por parametro.
*
* @precondition 		El timer tiene que estas inicializado e iniciado
*
* @param timerNumber 	uint8_t, entero con el numero de timer a inciar
*
* @return NONE
*/
void Timer_Stop(uint8_t timerNumber);

/** Obtiene el valor del contador del timer pasado por parametro.
*
* @precondition 		El timer tiene que estas inicializado e iniciado
*
* @param timerNumber 	uint8_t, entero con el numero de timer
*
* @return Valor del contador del timer, uint32_t.
*/
uint32_t TIMER_GetTime(uint8_t timerNumber);

#endif /* TIMER_H_ */
