/**
 * Description of module:
 * Libreria con herramientoas para el manejo de la comunicacion a traves de UART
 *
 * author Jorge Saiz Gil
 *
 * revision 1.0 date 31/03/2016
 */

#ifndef UARTPRINT_H_
#define UARTPRINT_H_

/*-----------------------------------------------------------
 * DEFINICIONES
 *----------------------------------------------------------*/
#define LONG_TIMEOUT	2000
#define SIMPLE_TIMEOUT	500
#define LARGE_TIMEOUT	4000

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/
#include <LPC17xx.h>

/** Envia el texto pasado por parametro a traves de UART
*
* @precondition 		El Puerto UART debe estar inicializado
*
* @param PortNum 		uint8_t, entero con el puerto UART a usar
* @param char 			char*, puntero a variable char donde esta el texto a imprimir
*
* @return NONE
*/
void UARTPrint_Text ( uint8_t PortNum , char * format, ...);

/** Envia el texto pasado por parametro a traves de UART y le añade fin de linea y salto de carro
*
* @precondition 		El Puerto UART debe estar inicializado
*
* @param PortNum 		uint8_t, entero con el puerto UART a usar
* @param char 			char*, puntero a variable char donde esta el texto a imprimir
*
* @return NONE
*/
void UARTPrint_Text_LF ( uint8_t PortNum , char * format, ...);

/** Imprime a traves del UART paquete UDP
*
* @precondition 		El Puerto UART debe estar inicializado
*
* @param PortNum 		uint8_t, entero con el puerto UART a usar
* @param char 			char*, puntero a variable char donde esta el contenido del paquete UDP
* @param Packet_Length	uint32_t, Entero con la longitud del paquete UDP
*
* @return NONE
*/
void UARTPrint_PacketUDP ( uint8_t PortNum , char * Packet, uint32_t Packet_Length);

/** Lee datos a traves del puerto UART
*
* @precondition 		El Puerto UART debe estar inicializado, en esta version solo funciona con el UART0
*
* @param PortNum 		uint8_t, entero con el puerto UART a usar
* @param Response		char*, puntero a variable char donde se almacenaran los datos obtenidos
* @param Time			uint32_t, Entero con el tiempo que se esparara para recibir datos
*
* @return Entero con el numero de caracteres leidos, uint32_t
*/
uint32_t UART_Scanf(uint8_t PortNum, char* Response, uint32_t Time);

/** Lee paquete NTP a traves del puerto UART
*
* @precondition 		El Puerto UART debe estar inicializado
*
* @param PortNum 		uint8_t, entero con el puerto UART a usar
* @param Packet			uint8_t*, puntero a Entero donde se almacenaran el paquete NTP recibido
* @param Time			uint32_t, Entero con el tiempo que se esparara para recibir datos
*
* @return Entero con el numero de caracteres leidos, uint32_t
*/
uint32_t UART_Read_NTP_Packet(uint8_t PortNum, uint8_t* Packet, uint32_t Time);

/** Lee datos a traves del puerto UART y compara el resultado con un valor pasado por parametro
*
* @precondition 		El Puerto UART debe estar inicializado
*
* @param PortNum 		uint8_t, entero con el puerto UART a usar
* @param Read_Buffer	char*, puntero a variable char donde se almacenaran los datos obtenidos
* @param value			char*, puntero a variable char que contiene la cadena a comparar.
* @param Time			uint32_t, Entero con el tiempo que se esparara para recibir datos
*
* @return 1 si los datos obtenidos contienen el valor buscado, 0 si no lo contiene.
*/
uint32_t UART_CheckRead(uint8_t PortNum, char* Read_Buffer,char* value, uint32_t Time);

/** Hace un delay de los ms pasados por parametro
*
* @precondition 		Deben estar inicializadas las tareas de FreeRTOS
*
* @param ms 			uint32_t, Entero con los ms a esperar
* 
* @return NONE
*/
void delayMs(uint32_t ms);


#endif /* UARTPRINT_H_ */
