/**
 * Description of module:
 * Libreria para gestionar la comunicacion con el modulo Wifly
 *
 * author Jorge Saiz Gil
 *
 * revision 1.0 date 18/04/2016
 */

#ifndef WIFLY_H_
#define WIFLY_H_

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/
#include <LPC17xx.h>
#include <GPIO.h>

/*-----------------------------------------------------------
 * DEFINICIONES
 *----------------------------------------------------------*/
#define WIFLY_RESET_PIN					P0_22	//pin donde se conecta el reset del wifly

/*-----------------------------------------------------------
 * DECLARATIONS
 *----------------------------------------------------------*/

/** Inicializa el modulo Wifly
*
* @precondition 		NONE
* @param PortNum 		uint8_t, entero con el puerto UART del WILFY
* @param Baudrate 		Baudrate, entero con el baudrate al que trabaja el modulo
* 
* @return NONE
*/
void WIFLY_Init( uint32_t portNum, uint32_t Baudrate );

/** Realiza la conexion a la red Wifi pasada por parametros
*
* @precondition 		El modulo wilfy debe estar inicializado
* 
* @param ssid 			char*, puntero a char donde esta el nombre del SSID de la re wifi
* @param pwd 			char*, puntero a char donde esta la contraseña dee la red wifi
* @param mode 			uint8_t, define el modo de seguridad de la red. 0->WPA 1->WEP128
* 
* @return NONE
*/
void WIFLY_Connect_WLAN(char* ssid, char* pwd, uint8_t mode);

/** Configura el servidor NTP y el puerto de conexion
*
* @precondition 		El modulo wilfy debe estar inicializado
* 
* @param server 		char*, puntero a char donde esta la ip del servidor NTP
* @param port 			char*, puntero a char donde esta el valor del puerto de conexion del servidor
* 
* @return NONE
*/
void WIFLY_ConfigNTP(char* server,char* port);

/** Realiza peticion de hora a servidor NTP utilizando la funcion interna del WILFY
*
* @precondition 		El modulo wilfy debe estar inicializado y configurado el servidor NTP
* 
* @return Devuelve timestamp de la hora obtenida, uint32_t
*/
uint32_t WIFLY_GetTime();

/** Comprueba el estado de la conexion a internet.
*
* @precondition 		El modulo wilfy debe estar inicializado
* 
* @return Devuelve TRUE (1) si esta conectado. FALSE (0) si no lo esta, uint8_t
*/
uint8_t WIFLY_CheckConnection();

/** Realiza peticion de hora a servidor NTP mediante paquetes UDP
*
* @precondition 		El modulo wilfy debe estar inicializado y configurado el servidor NTP
* 
* @return Devuelve timestamp de la hora obtenida, uint32_t
*/
uint32_t Wifly_NTP_request();

/** Pone el modulo wilfy en modo reposo
*
* @precondition 		El modulo wilfy debe estar inicializado y configurado el servidor NTP
* 
* @return Devuelve 1 si el modulo ha entrado en modo reposo, 0 si no. uint8_t
*/
uint8_t Wifly_SleepModule();

#endif /* WIFLY_H_ */
