/*
 * GPIO.c
 *
 *  Created on: 4 de may. de 2016
 *      Author: Jorge Saiz Gil
 */

#include <LPC17xx.h>
#include <GPIO.h>

void GPIO_PinFunction(uint8_t pinNumber, uint8_t pinFunction)
{
    uint8_t portNumber;
    uint32_t *ptr_PINCON;

	portNumber =  (pinNumber>>5);  //Divide the pin number by 32 go get the PORT number
	pinNumber  =   pinNumber & 0x1f;  //lower 5-bits contains the bit number of a 32bit port

	portNumber = portNumber*2;
	if(pinNumber>=16)
	{
		portNumber++;
		pinNumber = pinNumber-16;
	}

	pinNumber = pinNumber * 2;

	ptr_PINCON = ((uint32_t *)&LPC_PINCON->PINSEL0  + portNumber);

	*(uint32_t *)(ptr_PINCON) &= ~(0x03UL << pinNumber);
	*(uint32_t *)(ptr_PINCON) |= (((uint32_t)pinFunction) << pinNumber);

}

void GPIO_PinDirection(uint8_t pinNumber, uint8_t pinDir)
{

    uint8_t portNumber;
    LPC_GPIO_TypeDef *LPC_GPIO_PORT;

	portNumber =  (pinNumber>>5);  //Divide the pin number by 32 go get the PORT number
	pinNumber  =   pinNumber & 0x1f;  //lower 5-bits contains the bit number of a 32bit port

	/* Go to particular port after decoding from the pin number and
	set the direction as specified*/

	LPC_GPIO_PORT = (LPC_GPIO_TypeDef*)(LPC_GPIO_BASE + ((portNumber) << 5));
	UpdateBit(LPC_GPIO_PORT->FIODIR,pinNumber,pinDir);

}

void GPIO_PinWrite(uint8_t pinNumber, uint8_t pinValue)
{

    uint8_t portNumber;
    LPC_GPIO_TypeDef *LPC_GPIO_PORT;
	portNumber =  (pinNumber>>5);  //Divide the pin number by 32 go get the PORT number
	pinNumber  =   pinNumber & 0x1f;  //lower 5-bits contains the bit number of a 32bit port

	/* Go to particular port after decoding from the pin number and
	update the value of the specified pin*/

	LPC_GPIO_PORT = (LPC_GPIO_TypeDef*)(LPC_GPIO_BASE + ((portNumber) << 5));

	if(pinValue!=0)
	{
		BitSet(LPC_GPIO_PORT->FIOSET,pinNumber);
	}
	else
	{
		BitSet(LPC_GPIO_PORT->FIOCLR,pinNumber);
	}
}

