/*
 * LedDisplay.c
 *
 *  Created on: 6 de may. de 2016
 *      Author: Jorge Saiz Gil
 */

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/
#include <LedDisplay.h>
#include <FreeRTOS.h>
#include <semphr.h>

/*-----------------------------------------------------------
 * DECLARACIONES
 *----------------------------------------------------------*/
xSemaphoreHandle xMutexLedDisplay;

 /** Bloquea el uso del display led mediante un semaforo de FreeRTOS (Privada)
*
* @precondition 		La variable xMutexLedDisplay tiene que esta definida.
*
* @return NONE
*/
void _Lock_LedDisplay()
{
	if ( xMutexLedDisplay == NULL)
	{
		xMutexLedDisplay = xSemaphoreCreateRecursiveMutex();
	}
	xSemaphoreTakeRecursive( xMutexLedDisplay, portMAX_DELAY );
}

 /** Desbloquea el uso del display led mediante un semaforo de FreeRTOS (Privada)
*
* @precondition 		La variable xMutexLedDisplay tiene que esta definida.
*
* @return NONE
*/
void _UnLock_LedDisplay()
{
	xSemaphoreGiveRecursive( xMutexLedDisplay );
}

 /** Apaga todo los leds del panel.  (Privada)
*
* @precondition 		Los pines deben estar inicializados
*
* @return NONE
*/
void _LedDisplay_Alloff()
{
	uint8_t aux=0;
	_Lock_LedDisplay();
	while (aux<num_wordInPanel)
	{
		GPIO_PinWrite(wordsInPanel[aux], 0); // Todos los pines a cero
		aux++;
	}
	_UnLock_LedDisplay();
}

 /** Apaga el pin pasado por parametro (Privada)
*
* @precondition 		El pin deben estar inicializado
*
* @param DisplayWord  	Entero que contiene el pin del LPC a apagar, uint8_t
*
* @return NONE
*/
void _LedDisplay_off(uint8_t DisplayWord)
{
	_Lock_LedDisplay();
	GPIO_PinWrite(DisplayWord, 0);
	_UnLock_LedDisplay();
}

 /** Activa el pin pasado por parametro (Privada)
*
* @precondition 		El pin deben estar inicializado
*
* @param DisplayWord  	Entero que contiene el pin del LPC a activar, uint8_t
*
* @return NONE
*/
void _LedDisplay_on(uint8_t DisplayWord)
{
	_Lock_LedDisplay();
	GPIO_PinWrite(DisplayWord, 1);
	_UnLock_LedDisplay();
}

void LedDisplay_init()
{
	uint8_t aux=0;
	_Lock_LedDisplay();
	while (aux<num_wordInPanel)
	{
		GPIO_PinFunction(wordsInPanel[aux], PINSEL_FUNC_0);
		GPIO_PinDirection(wordsInPanel[aux], 1);
		aux++;
	}
	_LedDisplay_Alloff();
	_UnLock_LedDisplay();
}


void LedDisplay_showTime( Timedate *t)
{
	//uint8_t second = t->sec;
	uint8_t minute = t->min;
	uint8_t hour = t->hour;

	_Lock_LedDisplay();
	_LedDisplay_Alloff(); //apagamos todo

	if(minute >= 0 && minute <= 34 ) //primeros 34 minutos se dice es la/son las + hora actual
	{
		if (hour==1 || hour==13)
		{
			_LedDisplay_on(ES);
			_LedDisplay_on(LA);
		}
		else
		{
			_LedDisplay_on(SON);
			_LedDisplay_on(LA);
			_LedDisplay_on(S);
		}

		switch(hour)
		{
			case 1:
			case 13:
				_LedDisplay_on(UNA);
				break;
			case 2:
			case 14:
				_LedDisplay_on(DOS);
				break;
			case 3:
			case 15:
				_LedDisplay_on(TRES);
				break;
			case 4:
			case 16:
				_LedDisplay_on(CUATRO);
				break;
			case 5:
			case 17:
				_LedDisplay_on(CINCO);
				break;
			case 6:
			case 18:
				_LedDisplay_on(SEIS);
				break;
			case 7:
			case 19:
				_LedDisplay_on(SIETE);
				break;
			case 8:
			case 20:
				_LedDisplay_on(OCHO);
				break;
			case 9:
			case 21:
				_LedDisplay_on(NUEVE);
				break;
			case 10:
			case 22:
				_LedDisplay_on(DIEZ);
				break;
			case 11:
			case 23:
				_LedDisplay_on(ONCE);
				break;
			case 12:
			case 0:
				_LedDisplay_on(DOCE);
				break;
		}
	}
	else
	{
		if (hour==0 || hour==12)
		{
			_LedDisplay_on(ES);
			_LedDisplay_on(LA);
		}
		else
		{
			_LedDisplay_on(SON);
			_LedDisplay_on(LA);
			_LedDisplay_on(S);
		}
		switch(hour)
		{
			case 1:
			case 13:
				_LedDisplay_on(DOS);
				break;
			case 2:
			case 14:
				_LedDisplay_on(TRES);
				break;
			case 3:
			case 15:
				_LedDisplay_on(CUATRO);
				break;
			case 4:
			case 16:
				_LedDisplay_on(CINCO);
				break;
			case 5:
			case 17:
				_LedDisplay_on(SEIS);
				break;
			case 6:
			case 18:
				_LedDisplay_on(SIETE);
				break;
			case 7:
			case 19:
				_LedDisplay_on(OCHO);
				break;
			case 8:
			case 20:
				_LedDisplay_on(NUEVE);
				break;
			case 9:
			case 21:
				_LedDisplay_on(DIEZ);
				break;
			case 10:
			case 22:
				_LedDisplay_on(ONCE);
				break;
			case 11:
			case 23:
				_LedDisplay_on(DOCE);
				break;
			case 12:
			case 0:
				_LedDisplay_on(UNA);
				break;
		}

	}
	// desde minuto 5 hasta minuto 35 "Y", hasta minuto 59 "MENOS"
	if (minute >= 5 && minute <= 34 )
	{
		_LedDisplay_on(Y);
	}
	else if ( minute >=35 && minute <= 59 )
	{
		_LedDisplay_on(MENOS);
	}

	//controlamos que palabra correspondiente a los minutos hay que iluminar
	if ( minute >= 5 && minute <= 9)
	{
		_LedDisplay_on(M_CINCO);
	}
	if ( minute >= 10 && minute <= 14)
	{
		_LedDisplay_on(M_DIEZ);
	}
	if ( minute >= 15 && minute <= 19)
	{
		_LedDisplay_on(CUARTO);
	}
	if ( minute >= 20 && minute <= 24)
	{
		_LedDisplay_on(VEINTE);
	}
	if ( minute >= 25 && minute <= 29)
	{
		_LedDisplay_on(VEINTI);
		_LedDisplay_on(M_CINCO);
	}
	if ( minute >= 30 && minute <= 34)
	{
		_LedDisplay_on(MEDIA);
	}
	if ( minute >= 35 && minute <= 39)
	{
		_LedDisplay_on(VEINTI);
		_LedDisplay_on(M_CINCO);
	}
	if ( minute >= 40 && minute <= 44)
		{
			_LedDisplay_on(VEINTE);
		}
	if ( minute >= 45 && minute <= 49)
		{
			_LedDisplay_on(CUARTO);
		}
	if ( minute >= 50 && minute <= 54)
		{
			_LedDisplay_on(M_DIEZ);
		}
	if ( minute >= 55 && minute <= 59)
		{
			_LedDisplay_on(M_CINCO);
		}
	// iluminamos los indicadores de los minutos
	if ((minute-(minute/5)*5)==1)
	{
		_LedDisplay_on(MIN1);
	}
	if ((minute-(minute/5)*5)==2)
	{
		_LedDisplay_on(MIN1);
		_LedDisplay_on(MIN2);
	}
	if ((minute-(minute/5)*5)==3)
	{
		_LedDisplay_on(MIN1);
		_LedDisplay_on(MIN2);
		_LedDisplay_on(MIN3);
	}
	if ((minute-(minute/5)*5)==4)
	{
		_LedDisplay_on(MIN1);
		_LedDisplay_on(MIN2);
		_LedDisplay_on(MIN3);
		_LedDisplay_on(MIN4);
	}


	_UnLock_LedDisplay();

}

