/*
 * TimeTools.c
 *
 *  Created on: 3 de may. de 2016
 *      Author: Jorge Saiz Gil
 */

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/

#include <TimeTools.h>

/*-----------------------------------------------------------
 * DECLARATIONS
 *----------------------------------------------------------*/

// array con los dias que tiene cada mes
static const uint8_t daysInMonth[12] = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};

 /** Comprueba si el año pasado por parametro es bisiesto (Privada)
*
* @precondition 		NONE
*
* @param year  			Entero con el año a comprobar, uint8_t.
* 
* @return Entero, devuelve 1 si es bisiesto, 0 si no lo es
*/
uint8_t _isLeapYear(uint8_t year)
{
	uint8_t lY; // leapYear variable
	if((( year % 4 == 0 ) && ( year % 100 != 0 )) || ( year % 400 == 0 ))
	{
		lY = 1;
	}
	else
	{
		lY = 0;
	}
	return lY;
}

void Time_TimestamptoTimedate(uint32_t ts, Timedate *t)
{
	uint32_t seconds, minutes, hours, days, year, month, dayOfWeek;
	uint8_t	century, leapYear, dim;
	uint16_t daysInYear;

	seconds = ts;
	// Calcula los minutos
	minutes  = seconds / 60;
	seconds -= minutes * 60;
	// Calcula las horas
	hours    = minutes / 60;
	minutes -= hours   * 60;
	// Calcula los dias
	days     = hours   / 24;
	hours   -= days    * 24;


	year = 1900;
	dayOfWeek =
	// Unix time empieza el 1 de enero de 1970
	year      = 1970;
	dayOfWeek = 4;

	while(1)
	{
		leapYear = _isLeapYear(year);
		daysInYear = leapYear ? 366 : 365; // Si es año bisiesto el año tiene 366 dias sino 365
		if (days >= daysInYear)
		{
			dayOfWeek += leapYear ? 2 : 1; // ajusta el dia de la semana
			days -= daysInYear;
			if (dayOfWeek >= 7)
			{
				dayOfWeek -= 7;
			}
			++year;
		}
		else
		{
			dayOfWeek += days;
			dayOfWeek %= 7;

			// Calcula mes y dia
			for(month = 0; month < 12; ++month)
			{
				dim = daysInMonth[month];
				// Añade un dia a febrero si es bisiesto
				if (month == 1 && leapYear)
				{
					++dim;
				}
				if (days >= dim)
				{
					days -= dim;
				}
				else
				{
					break;
				}
			}
			break;
		}
	}
	// Calcula Century
	if (year - 2000 >= 0)
	{
		century = 1;
	}
	else
	{
		century = 0;
	}

	//Guarda los valores calculados
	t->hour = hours;
	t->min = minutes;
	t->sec = seconds;
	t->date = days;
	t->mon = month+1;
	t->year = year % 100;
	t->day = dayOfWeek;
	t->century = century;
}

uint32_t Time_TimedatetoTimestamp(Timedate *t)
{
	uint32_t ts = 0;
	uint8_t i; //variable auxiliar
	uint8_t second = t->sec;
	uint8_t minute = t->min;
	uint8_t hour = t->hour;
	uint8_t date = t->date;
	uint8_t month = t->mon-1;
	uint32_t year = t->year;
	uint8_t century = t->century;
	uint32_t epoch_year = 1970;

	uint32_t daysInYear;
	uint8_t leapYear;

	year += century ? 2000 : 1900;

	// Calucula los segundo desde epoch hasta el primer dia del año
	for ( epoch_year ; epoch_year < year ; epoch_year++ )
	{
		leapYear = _isLeapYear(epoch_year);
		daysInYear = leapYear ? 366 : 365; // Si es año bisiesto el año tiene 366 dias sino 365
		ts += daysInYear*24*60*60;
	}
	// Calcula los segundos desde el primer dia del año hasta el primer dia del mes
	leapYear = _isLeapYear(year);
	for (i=0;i<month;i++)
	{
		if (i == 1 && leapYear) //Si es bisiesto febrero tiene 29 dias
		{
			ts+= (daysInMonth[i]+1)*24*60*60;
		}
		else
		{
			ts+= daysInMonth[i]*24*60*60;
		}
	}

	//Sumamos todos los segundos para obtener el timestamp
	ts+=date*24*60*60;
	ts+=hour*60*60;
	ts+=minute*60;
	ts+=second;

	return ts;
}

uint32_t Time_adjustTimeZoneDST(uint32_t ts)
{
	Timedate xtime;
	Timedate* ptime = &xtime;

	Time_TimestamptoTimedate(ts,ptime);
	uint8_t date = xtime.date;
	uint8_t month = xtime.mon-1;
	uint8_t hour = xtime.hour;
	uint8_t dow = xtime.day;
	uint8_t prevSunday = date - dow;

	//ajustamos el horario de verano. Es desde el ultimo domingo de marzo a las 02:00 hasta el ultimo domingo de octubre a las 02:00
	if ((month > 3 && month < 10 ) ||
		(month ==  3 && prevSunday >= 25 && hour >= 2) ||
		(month == 11 && prevSunday < 25) ||
		(month == 11 && prevSunday < 25  && hour < 2))
	{
		ts += 3600 ; //añadimos una hora
	}
	//España esta en la zona UTC+1
	ts+=3600;

	return ts;

}
uint32_t Time_adjunstSyncDelay(uint32_t ts,uint32_t syncDelayUs)
{
	uint32_t RoundTime = 0;
	//syncDelayUs+=200000; // compesamos con 200ms por los procesos posteriores a la parada del timer.
	RoundTime = ((syncDelayUs + 500000) / 1000000) + ts;

	return RoundTime;
}

char bcd_to_decimal(char d)
{
	return ((d & 0x0F) + (((d & 0xF0) >> 4) * 10));
}

unsigned char decimal_to_bcd(unsigned char d)
{
         return (((d / 10) << 4) & 0xF0) | ((d % 10) & 0x0F);
}

