/*
 * Timer.c
 *
 *  Created on: 19 de may. de 2016
 *      Author: Jorge
 */

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/
#include <LPC17xx.h>
#include <Timer.h>

void Timer_init(uint8_t timerNumber)
{
	uint32_t pclkdiv;
	uint32_t pclk;

	if (timerNumber == 0)
	{
		// power Timer/Counter 0 module [bit 1]
		LPC_SC->PCONP |= (0<<1);
		pclkdiv = (LPC_SC->PCLKSEL0 >> 2) & 0x03; /* get the pclk info for required timer0/1 */
		switch (pclkdiv) {
		case 0x00:
			pclk = SystemCoreClock / 4; //global from system_LPC17xx.c
			break;
		case 0x01:
			pclk = SystemCoreClock;
			break;
		case 0x02:
			pclk = SystemCoreClock / 2;
			break;
		case 0x03:
			pclk = SystemCoreClock / 8;
			break;
		}
		// Timer Control Register: reset counter
		LPC_TIM0->TCR   = 0x02;

		// Prescale Register
		LPC_TIM0->PR    = pclk/TICS_PER_SECOND;

		//como solo queremos saber el tiempo que pasa no configuramos las interrupciones.
}

}
void Timer_Start(uint8_t timerNumber)
{
	if (timerNumber == 0)
	{
		LPC_TIM0->TC = 0x00;
		LPC_TIM0->TCR = 1;
	}
}
void Timer_Stop(uint8_t timerNumber)
{
	if (timerNumber == 0)
	{
		LPC_TIM0->TCR = 0x00; //
	}
}
uint32_t TIMER_GetTime(uint8_t timerNumber)
{
	uint32_t Current=0;
	if (timerNumber == 0)
	{
		Current = LPC_TIM0->TC; //recogemos el valor del contador
	}
	return Current;
}

