/*
 * UARTprint.c
 *
 *  Created on: 31 de mar. de 2016
 *      Author: Jorge Saiz Gil
 */

/*-----------------------------------------------------------
 * INCLUDES
 *----------------------------------------------------------*/

#include <LPC17xx.h>
#include <FreeRTOS.h>
#include <task.h>
#include <queue.h>
#include <semphr.h>


#include <stdio.h>
#include <string.h>
#include <stdarg.h>
#include <stdlib.h>

#include <type.h>
#include <uart.h>
#include <UARTprint.h>
#include <Config.h>

/*-----------------------------------------------------------
 * DECLARACIONES
 *----------------------------------------------------------*/
 
extern volatile uint32_t UART0Count;
extern volatile uint8_t UART0Buffer[BUFSIZE];

extern volatile uint32_t UART1Count;
extern volatile uint8_t UART1Buffer[BUFSIZE];

extern volatile uint32_t UART3Count;
extern volatile uint8_t UART3Buffer[BUFSIZE];


xSemaphoreHandle xMutexUARTPrint; 

/** Bloquea el uso del UART mediante un semaforo de FreeRTOS (Privada)
*
* @precondition 		La variable xMutexUARTPrint tiene que esta definida.
*
* @return NONE
*/
void _Lock_UARTPrint()
{
	if ( xMutexUARTPrint == NULL)
	{
		xMutexUARTPrint = xSemaphoreCreateRecursiveMutex();
	}
	xSemaphoreTakeRecursive( xMutexUARTPrint, portMAX_DELAY );
}

/** Desbloquea el uso del UART mediante un semaforo de FreeRTOS (Privada)
*
* @precondition 		La variable xMutexUARTPrint tiene que esta definida.
*
* @return NONE
*/
void _UnLock_UARTPrint()
{
	xSemaphoreGiveRecursive( xMutexUARTPrint );
}
void UARTPrint_Text ( uint8_t PortNum , char * format, ...)
{
	_Lock_UARTPrint();
	static char Send_Buffer[BUFSIZE];
	va_list args;
	va_start (args, format);
	vsprintf (Send_Buffer,format, args);
	va_end (args);
	uint32_t len =  strlen(Send_Buffer);
	UARTSend(PortNum, (uint8_t *)Send_Buffer ,len );
	_UnLock_UARTPrint();

}

void UARTPrint_Text_LF ( uint8_t PortNum , char * format, ...)
{
	_Lock_UARTPrint();
	static char Send_Buffer[BUFSIZE];
	va_list args;
	va_start (args, format);
	vsprintf (Send_Buffer,format, args);
	va_end (args);
	uint32_t len =  strlen(Send_Buffer);
	UARTSend(PortNum, (uint8_t *)Send_Buffer ,len );
	UARTSend(PortNum, (uint8_t *)"\r\n", 2);
	_UnLock_UARTPrint();
}

void UARTPrint_PacketUDP ( uint8_t PortNum , char * Packet, uint32_t Packet_Length)
{
	_Lock_UARTPrint();
	UARTSend(PortNum, (uint8_t *)Packet ,Packet_Length );
	_UnLock_UARTPrint();
}

uint32_t UART_Scanf(uint8_t PortNum, char* Cadena, uint32_t Time)
{
	uint32_t oldCount, newCount;
    _Lock_UARTPrint();
	UART_Clear(PortNum); // Limpiamos el buffer y contadores

	if ( PortNum == 0 )
	{
		UART0Count = 0;
		LPC_UART0->IER = IER_THRE | IER_RLS | IER_RBR; // enable interrupt RX UART0
		delayMs(Time); // wait sometime for receive some commands
		do{
			oldCount = newCount;
			delayMs(5);
			newCount = UART0Count;
		}while(oldCount != newCount); // wait a little time while we have new chars
		LPC_UART0->IER = IER_THRE | IER_RLS; // disable interrupt RX UART0
		strncpy(Cadena, (char*)UART0Buffer, newCount ); // Obtain UART data



	}
	else if ( PortNum == 1 )
	{
		UART1Count = 0;
		LPC_UART1->IER = IER_THRE | IER_RLS | IER_RBR; // enable interrupt RX UART0
		delayMs(Time); // wait sometime for receive some commands
		do{
			oldCount = newCount;
			delayMs(5);
			newCount = UART1Count;
		}while(oldCount != newCount); // wait a little time while we have new chars
		LPC_UART1->IER = IER_THRE | IER_RLS; // disable interrupt RX UART0
		strncpy(Cadena, (char *)UART1Buffer, newCount ); // Obtain UART data
	}
	else if ( PortNum == 3 )
	{
		UART3Count = 0;
		LPC_UART3->IER = IER_THRE | IER_RLS | IER_RBR; // enable interrupt RX UART0
		delayMs(Time); // wait sometime for receive some commands
		do{
			oldCount = newCount;
			delayMs(5);
			newCount = UART3Count;
		}while(oldCount != newCount); // wait a little time while we have new chars
		LPC_UART3->IER = IER_THRE | IER_RLS; // disable interrupt RX UART0
		strncpy(Cadena, (char *)UART3Buffer, newCount ); // Obtain UART data
	}

	Cadena[newCount] = '\0'; // add end string. Now we have a string
	UART_Clear(PortNum); // Erase and initialize UART buffer

	_UnLock_UARTPrint();
	return (newCount);
}

uint32_t UART_Read_NTP_Packet(uint8_t PortNum, uint8_t* Packet, uint32_t Time)
{
    _Lock_UARTPrint();

    uint8_t PacketSize=48; //NTP Packet size
    uint8_t curSize=0;
    uint8_t i;

	if (PortNum == 0 )
	{
		while ((curSize < PacketSize) && Time > 0 )
		{
			LPC_UART0->IER = IER_THRE | IER_RLS;				/* Disable RBR */

			if (UART0Count != 0)
			{
				Time++; 						// si hay datos esperamos un poco mas
				for(i=0;i<UART0Count;i++)		// obtenos los datos leidos
				{
					Packet[curSize]=UART0Buffer[i];
					curSize++;
				}
			}
		UART0Count = 0;
		LPC_UART0->IER = IER_THRE | IER_RLS | IER_RBR;		/* Re-enable RBR */
		Time--;
		delayMs(1);
		}


	}
	UART_Clear(PortNum);
	_UnLock_UARTPrint();
	return (curSize);
}

uint32_t UART_CheckRead(uint8_t PortNum, char* Read_Buffer,char* value, uint32_t Time)
{
	_Lock_UARTPrint();
	uint32_t ret = FALSE;
	uint32_t sizeResp = 0;
	sizeResp = UART_Scanf(PortNum,Read_Buffer,Time);
	if (sizeResp > 0)
	{
		if (strstr(Read_Buffer, value) != NULL) ret = TRUE;
	}

	_UnLock_UARTPrint();
	return ret;
}

void delayMs(uint32_t ms)
{
	const portTickType xDelay = ms / portTICK_RATE_MS;
	vTaskDelay(xDelay);

}





